@@ -30,6 +30,12 @@ class ContentSecurityService(Service):
                                    Credentials('', '', 'BusinessSecurity', 'cn-north-1'), 5, 5)
         return service_info
 
+    def set_socket_timeout(self, timeout):
+        self.service_info.socket_timeout = timeout
+
+    def set_connection_timeout(self, timeout):
+        self.service_info.connection_timeout = timeout
+
     @staticmethod
     def get_api_info():
         api_info = {"AsyncVideoRisk": ApiInfo("POST", "/", {"Action": "AsyncVideoRisk", "Version": "2021-11-29"}, {}, {}),
@@ -78,6 +84,7 @@ class ContentSecurityService(Service):
         res_json = json.loads(res)
         return res_json
 
+    # deprecated, use image_content_risk_v2 instead
     def image_content_risk(self, params, body):
         res = self.json("ImageContentRisk", params, json.dumps(body))
         if res == '':
@@ -131,6 +138,7 @@ class ContentSecurityService(Service):
 
     @redo.retriable(sleeptime=0.1, jitter=0.01, attempts=2,
                     retry_exceptions=(exceptions.ConnectionError, exceptions.ConnectTimeout))
+    # deprecated, use text_slice_risk instead
     def text_risk(self, params, body):
         res = self.json("TextRisk", params, json.dumps(body))
         if res == '':
@@ -241,4 +249,4 @@ class ContentSecurityService(Service):
         if res == '':
             raise Exception("empty response")
         res_json = json.loads(res)
-        return res_json
\ No newline at end of file
+        return res_json
