@@ -8,15 +8,16 @@ from volcengine.base.Service import Service
 from volcengine.ServiceInfo import ServiceInfo
 
 SERVICE_VERSION = "2021-04-01"
+SERVICE_VERSION_V2 = "2023-01-01"
 
 service_info = ServiceInfo("open.volcengineapi.com", {'Accept': 'application/json'},
                            Credentials('', '', 'dcdn', 'cn-north-1'), 60 * 5, 60 * 5, "https")
 
 api_info = {
-    # 查询域名列表: https://www.volcengine.com/docs/6559/95182
-    "DescribeUserDomains": ApiInfo("GET", "/", {
-        "Action": "DescribeUserDomains", "Version": SERVICE_VERSION}, {}, {}),
-
+    # 查询域名列表: https://www.volcengine.com/docs/6559/192391
+    "DescribeUserDomains": ApiInfo("POST", "/", {
+        "Action": "DescribeUserDomains", "Version": SERVICE_VERSION_V2}, {}, {}),
+    
     # 查询全站加速域名的详细配置: https://www.volcengine.com/docs/6559/94321
     "DescribeDomainConfig": ApiInfo("POST", "/", {
         "Action": "DescribeDomainConfig", "Version": SERVICE_VERSION}, {}, {}),
@@ -25,6 +26,10 @@ api_info = {
     "CreateDomain": ApiInfo("POST", "/", {
         "Action": "CreateDomain", "Version": SERVICE_VERSION}, {}, {}),
 
+    # 新增全站加速域名V2,支持识别Project: https://www.volcengine.com/docs/6559/191870
+    "CreateDomainV2": ApiInfo("POST", "/", {
+        "Action": "CreateDomain", "Version": SERVICE_VERSION_V2}, {}, {}),
+
     # 启动全站加速域名: https://www.volcengine.com/docs/6559/94320
     "StartDomain": ApiInfo("POST", "/", {
         "Action": "StartDomain", "Version": SERVICE_VERSION}, {}, {}),
@@ -41,6 +46,10 @@ api_info = {
     "UpdateDomainConfig": ApiInfo("POST", "/", {
         "Action": "UpdateDomainConfig", "Version": SERVICE_VERSION}, {}, {}),
 
+    # 变更域名配置V2,支持识别Project: https://www.volcengine.com/docs/6559/191883
+    "UpdateDomainConfigV2": ApiInfo("POST", "/", {
+        "Action": "UpdateDomainConfig", "Version": SERVICE_VERSION_V2}, {}, {}),
+
     # 查询域名的资源用量数据: https://www.volcengine.com/docs/6559/79733
     "DescribeStatistics": ApiInfo("POST", "/", {
         "Action": "DescribeStatistics", "Version": SERVICE_VERSION}, {}, {}),
@@ -120,6 +129,26 @@ api_info = {
     # 查询全站加速预热刷新任务Quota: https://www.volcengine.com/docs/6559/102403
     "RetryPurgePrefetchTask": ApiInfo("POST", "/", {
         "Action": "RetryPurgePrefetchTask", "Version": SERVICE_VERSION}, {}, {}),
+
+    # 更新全站加速域名拨测配置:
+    "UpdateDomainProbeSetting": ApiInfo("POST", "/", {
+        "Action": "UpdateDomainProbeSetting", "Version": SERVICE_VERSION}, {}, {}),
+
+    # 查询全站加速域名拨测配置:
+    "DescribeDomainProbeSetting": ApiInfo("POST", "/", {
+        "Action": "DescribeDomainProbeSetting", "Version": SERVICE_VERSION}, {}, {}),
+
+    # 获取边缘层节点的所有 IP:
+    "DescribeDcdnEdgeIp": ApiInfo("POST", "/", {
+        "Action": "DescribeDcdnEdgeIp", "Version": SERVICE_VERSION}, {}, {}),
+    
+    # 更新GA源站的回源策略:
+    "UpdateGAOriginPolicy": ApiInfo("POST", "/", {
+        "Action": "UpdateGAOriginPolicy", "Version": SERVICE_VERSION}, {}, {}),
+    
+    # 查询GA源站的回源策略:
+    "DescribeGAOriginPolicy": ApiInfo("POST", "/", {
+        "Action": "DescribeGAOriginPolicy", "Version": SERVICE_VERSION}, {}, {}),
 }
 
 
@@ -150,7 +179,7 @@ class DCDNService(Service):
         if params is None:
             params = {}
         action = "DescribeUserDomains"
-        res = self.get(action, params)
+        res = self.json(action,[], json.dumps(params))
         if res == '':
             raise Exception("%s: empty response" % action)
         res_json = json.loads(res)
@@ -175,6 +204,16 @@ class DCDNService(Service):
             raise Exception("%s: empty response" % action)
         res_json = json.loads(res)
         return res_json
+    
+    def create_domain_v2(self, params=None):
+        if params is None:
+            params = {}
+        action = "CreateDomainV2"
+        res = self.json(action, [], json.dumps(params))
+        if res == '':
+            raise Exception("%s: empty response" % action)
+        res_json = json.loads(res)
+        return res_json
 
     def start_domain(self, params=None):
         if params is None:
@@ -215,6 +254,16 @@ class DCDNService(Service):
             raise Exception("%s: empty response" % action)
         res_json = json.loads(res)
         return res_json
+    
+    def update_domain_config_v2(self, params=None):
+        if params is None:
+            params = {}
+        action = "UpdateDomainConfigV2"
+        res = self.json(action, [], json.dumps(params))
+        if res == '':
+            raise Exception("%s: empty response" % action)
+        res_json = json.loads(res)
+        return res_json
 
     def describe_statistics(self, params=None):
         if params is None:
@@ -415,3 +464,53 @@ class DCDNService(Service):
             raise Exception("%s: empty response" % action)
         res_json = json.loads(res)
         return res_json
+
+    def update_domain_probe_setting(self, params=None):
+        if params is None:
+            params = {}
+        action = "UpdateDomainProbeSetting"
+        res = self.json(action, [], json.dumps(params))
+        if res == '':
+            raise Exception("%s: empty response" % action)
+        res_json = json.loads(res)
+        return res_json
+
+    def describe_domain_probe_setting(self, params=None):
+        if params is None:
+            params = {}
+        action = "DescribeDomainProbeSetting"
+        res = self.json(action, [], json.dumps(params))
+        if res == '':
+            raise Exception("%s: empty response" % action)
+        res_json = json.loads(res)
+        return res_json
+
+    def describe_dcdn_edge_ip(self, params=None):
+        if params is None:
+            params = {}
+        action = "DescribeDcdnEdgeIp"
+        res = self.json(action, [], json.dumps(params))
+        if res == '':
+            raise Exception("%s: empty response" % action)
+        res_json = json.loads(res)
+        return res_json
+
+    def update_ga_origin_policy(self, params=None):
+        if params is None:
+            params = {}
+        action = "UpdateGAOriginPolicy"
+        res = self.json(action, [], json.dumps(params))
+        if res == '':
+            raise Exception("%s: empty response" % action)
+        res_json = json.loads(res)
+        return res_json
+    
+    def describe_ga_origin_policy(self, params=None):
+        if params is None:
+            params = {}
+        action = "DescribeGAOriginPolicy"
+        res = self.json(action, [], json.dumps(params))
+        if res == '':
+            raise Exception("%s: empty response" % action)
+        res_json = json.loads(res)
+        return res_json
