@@ -16,7 +16,8 @@ if __name__ == '__main__':
 
     params = {
         "PageNum": 1,
-        "PageSize": 10
+        "PageSize": 10,
+        "ProjectName": ["TEST"],
     }
 
     resp = svc.describe_user_domains(params)
