@@ -13,18 +13,11 @@ if __name__ == '__main__':
         with open(file, 'rb') as fileObj:
             image_data = fileObj.read()
             return base64.b64encode(image_data).decode('utf-8')
-
-
-    # oversea
-    # sms_service = SmsService(REGION_AP_SINGAPORE1)
     # cn
     sms_service = SmsService()
-
     # call below method if you dont set ak and sk in $HOME/.volc/config
     sms_service.set_ak('ak')
     sms_service.set_sk('sk')
-    # sms_service.set_scheme("http")
-    # sms_service.set_scheme("https")
     # sms_service.set_host('host')
     file_base64_string = to_base64_str("媒体文件路径")
     body = {
@@ -40,7 +33,7 @@ if __name__ == '__main__':
             },
             {
                 # choose the midea type
-                "sourceType": Source_TYPE_IMAGE_GIF,
+                "sourceType": SOURCE_TYPE_IMAGE_GIF,
                 "content": file_base64_string
             }
         ]
