@@ -6,15 +6,15 @@ from volcengine.visual.VisualService import VisualService
 if __name__ == '__main__':
     visual_service = VisualService()
 
-    # call below method if you dont set ak and sk in $HOME/.volc/config
+    # call below method if you don't set ak and sk in $HOME/.volc/config
     visual_service.set_ak('ak')
     visual_service.set_sk('sk')
-    # visual_service.set_host('host')
-
-    params = dict()
 
     form = {
-        "image_base64": "image_base64_str"
+
+        "image_url":"https://xxx",
+        "return_foreground_image":0
+
     }
 
     resp = visual_service.general_segment(form)
