@@ -12,11 +12,13 @@ if __name__ == '__main__':
     try:
         req = VodDescribeVodDomainBandwidthDataRequest()
         req.DomainList = ""
+        req.DomainInSpaceList = ""
         req.StartTime = ""
         req.EndTime = ""
         req.Aggregation = 0
         req.BandwidthType = ""
         req.Area = ""
+        req.RegionList = ""
         resp = vod_service.describe_vod_domain_bandwidth_data(req)
     except Exception:
         raise
