@@ -11,12 +11,14 @@ if __name__ == '__main__':
     vod_service.set_sk('your sk')
     try:
         req = VodDescribeVodDomainTrafficDataRequest()
-
         req.DomainList = ""
+        req.DomainInSpaceList = ""
         req.StartTime = ""
         req.EndTime = ""
         req.Aggregation = 0
         req.TrafficType = ""
+        req.Area = ""
+        req.RegionList = ""
         resp = vod_service.describe_vod_domain_traffic_data(req)
     except Exception:
         raise
