@@ -7,13 +7,14 @@ from volcengine.vod.models.request.request_vod_pb2 import VodGetPlayInfoRequest
 if __name__ == '__main__':
     vod_service = VodService()
     # call below method if you dont set ak and sk in $HOME/.vcloud/config
-    # vod_service.set_ak('ak')
-    # vod_service.set_sk('sk')
+    vod_service.set_ak('your ak')
+    vod_service.set_sk('your sk')
     try:
         vid = 'your vid'
         req = VodGetPlayInfoRequest()
         req.Vid = vid
         req.Ssl = '1'
+        req.NeedOriginal = '1'
         req.UnionInfo = 'your unionInfo'
         resp = vod_service.get_play_info(req)
     except Exception:
