@@ -256,6 +256,7 @@ class ImageXService(Service):
             'SessionKey': params.get('SessionKey', ''),
             'UploadNum': len(img_datas),
             'StoreKeys': params.get('StoreKeys', []),
+            'Overwrite': str(params.get('Overwrite', False)),
         }
         resp = self.apply_upload(apply_upload_request)
         if 'Error' in resp['ResponseMetadata']:
@@ -317,6 +318,23 @@ class ImageXService(Service):
         else:
             return base64.b64encode(data.decode('utf-8'))
 
+    # tag 字段如下，可选择所需字段传入
+    # upload_policy_dict = {
+    #     "FileSizeUpLimit": "xxx",
+    #     "FileSizeBottomLimit": "xxx",
+    #     "ContentTypeBlackList":[
+    #         "xxx"
+    #     ],
+    #     "ContentTypeWhiteList":[
+    #         "xxx"
+    #     ]
+    # }
+    # policy_str = json.dumps(upload_policy_dict)
+    #
+    # tag = {
+    #     "UploadOverwrite": "true",
+    #     "UploadPolicy": policy_str,
+    # }
     def get_upload_auth(self, service_ids, expire=60 * 60, key_ptn='', tag=dict):
         apply_res = []
         commit_res = []
@@ -446,7 +464,16 @@ class ImageXService(Service):
         return res_json['Result']
 
     def get_image_ocr_v2(self, params):
-        res = self.post('GetImageOCRV2', params, {})
+        query = {
+            'ServiceId': params['ServiceId']
+        }
+        body = {
+            'Scene': params['Scene'],
+            'StoreUri': params.get('StoreUri', None),
+            'ImageUrl': params.get('ImageUrl', None),
+            'InstrumentName': params.get('InstrumentName', None)
+        }
+        res = self.imagex_post('GetImageOCRV2', query, json.dumps(body))
         if res == '':
             raise Exception("%s: empty response" % 'GetImageOCR')
         res_json = json.loads(res)
