@@ -3,8 +3,6 @@ import sys
 import json
 import copy
 
-from google.protobuf.json_format import Parse
-
 from volcengine.ApiInfo import ApiInfo
 from volcengine.Credentials import Credentials
 from volcengine.base.Service import Service
@@ -12,8 +10,8 @@ from volcengine.ServiceInfo import ServiceInfo
 from volcengine.auth.SignerV4 import SignerV4
 
 from .sse_decoder import SSEDecoder
-from .models.api.api_pb2 import ChatResp, CertResp
 from .exception import MaasException, new_client_sdk_request_error
+from .utils import json_to_object
 
 
 class MaasService(Service):
@@ -33,107 +31,161 @@ class MaasService(Service):
         api_info = {
             "chat": ApiInfo("POST", "/api/v1/chat", {}, {}, {}),
             "cert": ApiInfo("POST", "/api/v1/cert", {}, {}, {}),
+            "tokenization": ApiInfo("POST", "/api/v1/tokenization", {}, {}, {}),
+            "classification": ApiInfo("POST", "/api/v1/classification", {}, {}, {}),
+            "embeddings": ApiInfo("POST", "/api/v1/embeddings", {}, {}, {}),
         }
         return api_info
 
     def chat(self, req, is_secret=False):
-        self._validate(is_secret)
+        self._validate(is_secret, req)
         try:
             req['stream'] = False
             if is_secret:
                 key, nonce, req = self.encrypt_chat_request(req)
-            res = self.json("chat", {}, json.dumps(req))
+            res = self.json("chat", {}, json.dumps(req).encode("utf-8"))
             if res == '':
-                raise new_client_sdk_request_error("empty response")
-            resp = Parse(res, ChatResp(), True)
+                raise new_client_sdk_request_error("empty response", req.get('req_id', None))
+            resp = json_to_object(res)
             if is_secret:
                 self.decrypt_chat_response(key, nonce, resp)
         except Exception as e:
             try:
-                resp = Parse(str(e.args[0], encoding='utf-8'), ChatResp(), True)
+                resp = json_to_object(str(e.args[0], encoding='utf-8'))
             except Exception:
-                raise new_client_sdk_request_error(str(e))
+                raise new_client_sdk_request_error(str(e), req.get('req_id', None))
             else:
-                raise MaasException(resp.error.code_n, resp.error.code, resp.error.message)
+                raise MaasException(resp.error.code_n, resp.error.code, resp.error.message, resp.req_id)
         else:
             return resp
 
-    def _validate(self, is_secret):
+    def _validate(self, is_secret, req):
         if self.service_info.credentials is None or \
             self.service_info.credentials.sk is None or \
             self.service_info.credentials.ak is None:
-            raise new_client_sdk_request_error("no valid credential")
-        
+            raise new_client_sdk_request_error("no valid credential", req.get('req_id', None))
+
         if is_secret and (sys.version_info < (3, 6)):
-            raise new_client_sdk_request_error("For content encryption, python version must be 3.6 or above")
+            raise new_client_sdk_request_error("For content encryption, python version must be 3.6 or above", req.get('req_id', None))
 
     def stream_chat(self, req, is_secret=False):
-        self._validate(is_secret)
-        
+        self._validate(is_secret, req)
+
         try:
             req['stream'] = True
             if is_secret:
                 key, nonce, req = self.encrypt_chat_request(req)
-            
+
             if not ("chat" in self.api_info):
-                raise new_client_sdk_request_error("no such api")
+                raise new_client_sdk_request_error("no such api", req.get('req_id', None))
             api_info = self.api_info["chat"]
             r = self.prepare_request(api_info, {})
             r.headers['Content-Type'] = 'application/json'
-            r.body = json.dumps(req)
+            r.body = json.dumps(req).encode("utf-8")
 
             SignerV4.sign(r, self.service_info.credentials)
 
             url = r.build()
             res = self.session.post(url, headers=r.headers, data=r.body,
-                                    timeout=(self.service_info.connection_timeout, self.service_info.socket_timeout), 
+                                    timeout=(self.service_info.connection_timeout, self.service_info.socket_timeout),
                                     stream=True)
             if res.status_code != 200:
                 raw = res.text.encode()
                 res.close()
                 try:
-                    resp = Parse(raw, ChatResp(), True)
+                    resp = json_to_object(str(raw, encoding='utf-8'))
                 except Exception:
-                    raise new_client_sdk_request_error(raw)
+                    raise new_client_sdk_request_error(raw, req.get('req_id', None))
                 else:
-                    raise MaasException(resp.error.code_n, resp.error.code, resp.error.message)
+                    raise MaasException(resp.error.code_n, resp.error.code, resp.error.message, resp.req_id)
 
             decoder = SSEDecoder(res)
-            
+
             def iter():
                 for data in decoder.next():
+                    if data == b'[DONE]':
+                        return
+
                     try:
-                        res = Parse(data, ChatResp(), True)
+                        res = json_to_object(str(data, encoding='utf-8'))
                         if is_secret:
                             self.decrypt_chat_response(key, nonce, res)
                     except:
-                        pass
+                        raise
                     else:
-                        if res.error.code_n != 0:
-                            raise MaasException(res.error.code_n, res.error.code, res.error.message)
+                        if res.error is not None and res.error.code_n != 0:
+                            raise MaasException(res.error.code_n, res.error.code, res.error.message, res.req_id)
                         yield res
-            
+
             return iter()
         except MaasException:
             raise
         except Exception as e:
-            raise new_client_sdk_request_error(str(e))
+            raise new_client_sdk_request_error(str(e), req.get('req_id', None))
+
+    def tokenize(self, req):
+        try:
+            res = self.json("tokenization", {}, json.dumps(req).encode("utf-8"))
+            if res == '':
+                raise new_client_sdk_request_error("empty response", req.get('req_id', None))
+            resp = json_to_object(res)
+        except Exception as e:
+            try:
+                resp = json_to_object(str(e.args[0], encoding='utf-8'))
+            except Exception:
+                raise new_client_sdk_request_error(str(e), req.get('req_id', None))
+            else:
+                raise MaasException(resp.error.code_n, resp.error.code, resp.error.message, resp.req_id)
+        else:
+            return resp
+
+    def classification(self, req):
+        try:
+            res = self.json("classification", {}, json.dumps(req).encode("utf-8"))
+            if res == '':
+                raise new_client_sdk_request_error("empty response", req.get('req_id', None))
+            resp = json_to_object(res)
+        except Exception as e:
+            try:
+                resp = json_to_object(str(e.args[0], encoding='utf-8'))
+            except Exception:
+                raise new_client_sdk_request_error(str(e), req.get('req_id', None))
+            else:
+                raise MaasException(resp.error.code_n, resp.error.code, resp.error.message, resp.req_id)
+        else:
+            return resp
+
+    def embeddings(self, req):
+        try:
+            res = self.json("embeddings", {}, json.dumps(req).encode("utf-8"))
+            if res == '':
+                raise new_client_sdk_request_error("empty response", req.get('req_id', None))
+            resp = json_to_object(res)
+        except Exception as e:
+            try:
+                resp = json_to_object(str(e.args[0], encoding='utf-8'))
+            except Exception:
+                raise new_client_sdk_request_error(str(e), req.get('req_id', None))
+            else:
+                raise MaasException(resp.error.code_n, resp.error.code, resp.error.message, resp.req_id)
+        else:
+            return resp
 
     def init_cert_by_req(self, req):
         cert_req = {"model": req['model']}
         try:
-            resp = self.json("cert", {}, json.dumps(cert_req))
-            resp = Parse(resp, CertResp(), True)
+            resp = self.json("cert", {}, json.dumps(cert_req).encode("utf-8"))
+            resp = json_to_object(resp)
             req['model']['endpoint_id'] = resp.model.endpoint_id
             if resp.cert is None or len(resp.cert) == 0:
-                raise new_client_sdk_request_error("No cert found, cannot use secret mode") 
+                raise new_client_sdk_request_error("No cert found, cannot use secret mode", req.get('req_id', None))
             from .ka_mgr import key_agreement_client
             return key_agreement_client(resp.cert)
         except ImportError:
             raise new_client_sdk_request_error(
-                "Please install the cryptography package manually by using pip install cryptography~=38.0")
+                "Please install the cryptography package manually by using pip install cryptography~=38.0", req.get('req_id', None))
         except Exception as e:
-            raise new_client_sdk_request_error(str(e))
+            raise new_client_sdk_request_error(str(e), req.get('req_id', None))
 
     def encrypt_chat_request(self, req):
         req_c = copy.deepcopy(req)
@@ -144,7 +196,7 @@ class MaasService(Service):
         for i in req_c['messages']:
             if i['content'] != '':
                 i['content'] = aes_gcm_encrypt_base64_string(key, nonce, i['content'])
-        
+
         return key, nonce, req_c
 
     def decrypt_chat_response(self, key, nonce, resp):
