@@ -2,4 +2,4 @@ from .MaasService import MaasService
 from .exception import MaasException
 from .utils import ChatRole
 
-__all__ = ['MaasService', "MaasException", "ChatRole"]
\ No newline at end of file
+__all__ = ['MaasService', 'MaasException', 'ChatRole']
