@@ -47,15 +47,40 @@ class TLSData:
         return json_data
 
 
+class TagInfo(TLSData):
+    def __init__(self, key: str, value: str = None):
+        """
+        :param key: 标签Key的值
+        :param value: 标签Value的值
+        """
+        self.key = key
+        self.value = value
+
+
 class ProjectInfo(TLSData):
     def __init__(self, project_name: str = None, project_id: str = None, description: str = None,
-                 create_time: str = None, inner_net_domain: str = None, topic_count: int = None):
+                 create_time: str = None, inner_net_domain: str = None, topic_count: int = None,
+                 iam_project_name: str = None, tags: List[TagInfo] = None):
         self.project_name = project_name
         self.project_id = project_id
         self.description = description
         self.create_time = create_time
         self.inner_net_domain = inner_net_domain
         self.topic_count = topic_count
+        self.iam_project_name = iam_project_name
+        self.tags = tags
+
+    @classmethod
+    def set_attributes(cls, data: dict):
+        project_info = super(ProjectInfo, cls).set_attributes(data)
+
+        if TAGS in data:
+            tags = data[TAGS]
+            project_info.tags = []
+            for i in range(len(tags)):
+                project_info.tags.append(TagInfo(tags[i].get(KEY), tags[i].get(VALUE)))
+
+        return project_info
 
     def get_inner_net_domain(self):
         """
@@ -99,15 +124,19 @@ class ProjectInfo(TLSData):
         """
         return self.topic_count
 
+    def get_iam_project_name(self):
+        """
+        :return: 日志项目所属的IAM项目
+        :rtype: str
+        """
+        return self.iam_project_name
 
-class TagInfo(TLSData):
-    def __init__(self, key: str, value: str = None):
+    def get_tags(self):
         """
-        :param key: 标签Key的值
-        :param value: 标签Value的值
+        :return: 日志项目标签信息
+        :rtype: List[TagInfo]
         """
-        self.key = key
-        self.value = value
+        return self.tags
 
 
 class TopicInfo(TLSData):
@@ -146,14 +175,17 @@ class TopicInfo(TLSData):
         enable_tracking = data.get(ENABLE_TRACKING)
         time_key = data.get(TIME_KEY)
         time_format = data.get(TIME_FORMAT)
-        tags = data.get(TAGS)
+        topic_tags = None
         log_public_ip = data.get(LOG_PUBLIC_IP)
 
-        for i in range(len(tags)):
-            tags[i] = TagInfo(tags[i][KEY], tags[i][VALUE])
+        tags = data.get(TAGS)
+        if tags is not None:
+            topic_tags = []
+            for i in range(len(tags)):
+                topic_tags.append(TagInfo(tags[i].get(KEY), tags[i].get(VALUE)))
 
         return cls(topic_name, topic_id, project_id, ttl, create_time, modify_time, shard_count, description,
-                   auto_split, max_split_shard, enable_tracking, time_key, time_format, tags, log_public_ip)
+                   auto_split, max_split_shard, enable_tracking, time_key, time_format, topic_tags, log_public_ip)
 
     def get_create_time(self):
         """
@@ -672,7 +704,8 @@ class HostGroupInfo(TLSData):
                  host_identifier: str = None, host_count: int = None, normal_heartbeat_status_count: int = None,
                  abnormal_heartbeat_status_count: int = None, rule_count: int = None,
                  create_time: str = None, modify_time: str = None, auto_update: bool = False,
-                 update_start_time: str = None, update_end_time: str = None, agent_latest_version: str = None):
+                 update_start_time: str = None, update_end_time: str = None, agent_latest_version: str = None,
+                 service_logging: bool = None, iam_project_name: str = None):
         self.host_group_id = host_group_id
         self.host_group_name = host_group_name
         self.host_group_type = host_group_type
@@ -687,105 +720,121 @@ class HostGroupInfo(TLSData):
         self.update_start_time = update_start_time
         self.update_end_time = update_end_time
         self.agent_latest_version = agent_latest_version
+        self.service_logging = service_logging
+        self.iam_project_name = iam_project_name
 
     def get_update_end_time(self):
         """
-        :return:自动升级的结束时间
+        :return: 自动升级的结束时间
         :rtype: str
         """
         return self.update_end_time
 
     def get_update_start_time(self):
         """
-        :return:自动升级的开始时间
+        :return: 自动升级的开始时间
         :rtype: str
         """
         return self.update_start_time
 
     def get_create_time(self):
         """
-        :return:机器组创建的时间
-        :rtype:str
+        :return: 机器组创建时间
+        :rtype: str
         """
         return self.create_time
 
     def get_host_count(self):
         """
-        :return:机器数量
-        :rtype:int
+        :return: 机器数量
+        :rtype: int
         """
         return self.host_count
 
     def get_modify_time(self):
         """
-        :return:机器组修改的时间
-        :rtype:str
+        :return: 机器组修改时间
+        :rtype: str
         """
         return self.modify_time
 
     def get_host_group_type(self):
         """
-        :return:机器组的类型
-        :rtype:str
+        :return: 机器组类型
+        :rtype: str
         """
         return self.host_group_type
 
     def get_host_group_id(self):
         """
-        :return:机器组的ID
-        :rtype:str
+        :return: 机器组ID
+        :rtype: str
         """
         return self.host_group_id
 
     def get_host_identifier(self):
         """
-        :return:机器的标识符
-        :rtype:str
+        :return: 机器标识符
+        :rtype: str
         """
         return self.host_identifier
 
     def get_abnormal_heartbeat_status_count(self):
         """
-        :return:心跳异常的机器数量
-        :rtype:int
+        :return: 心跳异常的机器数量
+        :rtype: int
         """
         return self.abnormal_heartbeat_status_count
 
     def get_auto_update(self):
         """
-        :return:是否开启自动升级功能
+        :return: 是否开启自动升级功能
         :rtype: bool
         """
         return self.auto_update
 
     def get_host_group_name(self):
         """
-        :return:机器组的名称
+        :return: 机器组名称
         :rtype: str
         """
         return self.host_group_name
 
     def get_agent_latest_version(self):
         """
-        :return:日志服务发布的 LogCollector 最新版本号
+        :return: 日志服务发布的LogCollector最新版本号
         :rtype: str
         """
         return self.agent_latest_version
 
     def get_normal_heartbeat_status_count(self):
         """
-        :return:心跳正常的机器数量
-        :rtype:int
+        :return: 心跳正常的机器数量
+        :rtype: int
         """
         return self.normal_heartbeat_status_count
 
     def get_rule_count(self):
         """
-        :return:绑定的采集配置的数量
-        :rtype:int
+        :return: 绑定的采集配置的数量
+        :rtype: int
         """
         return self.rule_count
 
+    def get_service_logging(self):
+        """
+        :return: 是否开启Logcollector服务日志功能
+        :rtype: bool
+        """
+        return self.service_logging
+
+    def get_iam_project_name(self):
+        """
+        :return: 机器组所属的IAM项目
+        :rtype: str
+        """
+        return self.iam_project_name
+
 
 class FilterKeyRegex(TLSData):
     def __init__(self, key: str, regex: str):
@@ -992,20 +1041,24 @@ class ShardHashKey(TLSData):
 
 
 class Plugin(TLSData):
-    def __init__(self, processors: Dict):
+    def __init__(self, processors: List[Dict]):
         """
         :param processors: LogCollector插件
-        :type processors: Dict
+        :type processors: List[Dict]
         """
         self.processors = processors
 
     def get_processors(self):
         """
         :return: LogCollector插件
-        :rtype: Dict
+        :rtype: List[Dict]
         """
         return self.processors
 
+    def json(self):
+        return {PROCESSORS: self.processors}
+
+
 class Advanced(TLSData):
     def __init__(self, close_inactive: int = 60, close_timeout: int = 0,
                  close_removed: bool = False, close_renamed: bool = False, close_eof: bool = False):
@@ -1153,7 +1206,7 @@ class UserDefineRule(TLSData):
         if PARSE_PATH_RULE in data:
             user_define_rule.parse_path_rule = ParsePathRule.set_attributes(data[PARSE_PATH_RULE])
         if PLUGIN in data:
-            user_define_rule.plugin = Plugin(processors=data[PLUGIN])
+            user_define_rule.plugin = Plugin(processors=data[PLUGIN].get(PROCESSORS))
         if ADVANCED in data:
             user_define_rule.advanced = Advanced(close_inactive=data[ADVANCED].get(CLOSE_INACTIVE),
                                                  close_timeout=data[ADVANCED].get(CLOSE_TIMEOUT),
@@ -1170,6 +1223,8 @@ class UserDefineRule(TLSData):
             json_data[SHARD_HASH_KEY] = self.shard_hash_key.json()
         if self.parse_path_rule is not None:
             json_data[PARSE_PATH_RULE] = self.parse_path_rule.json()
+        if self.plugin is not None:
+            json_data[PLUGIN] = self.plugin.json()
         if self.advanced is not None:
             json_data[ADVANCED] = self.advanced.json()
 
@@ -1579,18 +1634,18 @@ class QueryRequest(TLSData):
     def __init__(self, topic_id: str, query: str, number: int,
                  start_time_offset: int, end_time_offset: int, topic_name: str = None):
         """
-        :param topic_id:日志主题 ID
-        :type topic_id:str
-        :param query:查询语句，支持的最大长度为 1024
-        :type query:str
-        :param number:告警对象序号；从 1 开始递增
-        :type number:int
-        :param start_time_offset:查询范围起始时间相对当前的历史时间，单位为分钟，取值为非正，最大值为 0，最小值为 -1440
-        :type start_time_offset:int
-        :param end_time_offset:查询范围终止时间相对当前的历史时间，单位为分钟，取值为非正，须大于StartTimeOffset，最大值为 0，最小值为 -1440
-        :type end_time_offset:int
-        :param topic_name:告警策略执行的日志主题名称
-        :type topic_name:str
+        :param topic_id: 日志主题ID
+        :type topic_id: str
+        :param query: 查询语句，支持的最大长度为1024
+        :type query: str
+        :param number: 告警对象序号（从1开始递增）
+        :type number: int
+        :param start_time_offset: 查询范围起始时间相对当前的历史时间，单位为分钟，取值为非正，最大值为0，最小值为-1440
+        :type start_time_offset: int
+        :param end_time_offset: 查询范围终止时间相对当前的历史时间，单位为分钟，取值为非正，须大于StartTimeOffset，最大值为0，最小值为-1440
+        :type end_time_offset: int
+        :param topic_name: 告警策略执行的日志主题名称
+        :type topic_name: str
         """
         self.topic_id = topic_id
         self.query = query
@@ -1650,7 +1705,7 @@ class QueryRequest(TLSData):
         start_time_offset = data.get(START_TIME_OFFSET)
         end_time_offset = data.get(END_TIME_OFFSET)
 
-        return cls(topic_id, topic_name, query, number, start_time_offset, end_time_offset)
+        return cls(topic_id, query, number, start_time_offset, end_time_offset, topic_name)
 
 
 class RequestCycle(TLSData):
@@ -1916,10 +1971,14 @@ class AlarmInfo(TLSData):
             for alarm_notify_group in data[ALARM_NOTIFY_GROUP]:
                 alarm_info.alarm_notify_group.append(AlarmNotifyGroupInfo.set_attributes(data=alarm_notify_group))
         if ALARM_PERIOD_DETAIL in data:
-            alarm_info.alarm_period_detail = AlarmPeriodSetting(sms=data[ALARM_PERIOD_DETAIL][SMS],
-                                                                phone=data[ALARM_PERIOD_DETAIL][PHONE],
-                                                                email=data[ALARM_PERIOD_DETAIL][EMAIL],
-                                                                general_webhook=data[ALARM_PERIOD_DETAIL][GENERAL_WEBHOOK])
+            if len(data[ALARM_PERIOD_DETAIL]) == 0:
+                alarm_info.alarm_period_detail = None
+            else:
+                sms = data[ALARM_PERIOD_DETAIL].get(SMS)
+                phone = data[ALARM_PERIOD_DETAIL].get(PHONE)
+                email = data[ALARM_PERIOD_DETAIL].get(EMAIL)
+                general_webhook = data[ALARM_PERIOD_DETAIL].get(GENERAL_WEBHOOK)
+                alarm_info.alarm_period_detail = AlarmPeriodSetting(sms, phone, email, general_webhook)
 
         return alarm_info
 
