@@ -33,27 +33,42 @@ class TLSRequest:
 
 
 class CreateProjectRequest(TLSRequest):
-    def __init__(self, project_name: str, region: str, description: str = None):
+    def __init__(self, project_name: str, region: str, description: str = None,
+                 iam_project_name: str = None, tags: List[TagInfo] = None):
         """
-        :param project_name:日志项目的名称
-        :type project_name:str
-        :param region:地域
-        :type region:str
-        :param description:日志项目描述信息
-        :type description:str
+        :param project_name: 日志项目的名称
+        :type project_name: str
+        :param region: 地域
+        :type region: str
+        :param description: 日志项目描述信息
+        :type description: str
+        :param iam_project_name: 当前创建的日志项目所属的IAM项目（未指定此参数时，日志服务会将日志项目添加到名为default的IAM项目中）
+        :type iam_project_name: str
+        :param tags: 日志项目标签信息
+        :type tags: List[TagInfo]
         """
         self.project_name = project_name
         self.region = region
         self.description = description
+        self.iam_project_name = iam_project_name
+        self.tags = tags
 
     def check_validation(self):
         """
         :return: 参数是否合法
         :rtype: bool
         """
-        if self.project_name is None or self.region is None:
-            return False
-        return True
+        return self.project_name is not None and self.region is not None
+
+    def get_api_input(self):
+        body = super(CreateProjectRequest, self).get_api_input()
+
+        if self.tags is not None:
+            body[TAGS] = []
+            for tag in self.tags:
+                body[TAGS].append(tag.json())
+
+        return body
 
 
 class DeleteProjectRequest(TLSRequest):
@@ -118,25 +133,32 @@ class DescribeProjectRequest(TLSRequest):
 
 class DescribeProjectsRequest(TLSRequest):
     def __init__(self, page_number: int = 1, page_size: int = 20,
-                 project_name: str = None, project_id: str = None, is_full_name: bool = False):
+                 project_name: str = None, project_id: str = None, is_full_name: bool = False,
+                 iam_project_name: str = None, tags: List[TagInfo] = None):
         """
 
-        :param page_number: 分页查询时的页码。默认为 1
+        :param page_number: 分页查询时的页码（默认为1）
         :type page_number: int
-        :param page_size: 分页大小。默认为 20，最大为 100
+        :param page_size: 分页大小（默认为20，最大为100）
         :type page_size: int
         :param project_name: 日志项目的名称
-        :type project_name:str
-        :param project_id: 日志项目 ID
-        :type project_id: string
-        :param is_full_name: 根据 ProjectName 筛选时，是否精确匹配
+        :type project_name: str
+        :param project_id: 日志项目ID
+        :type project_id: str
+        :param is_full_name: 根据ProjectName筛选时，是否精确匹配
         :type is_full_name: bool
+        :param iam_project_name: 当前创建的日志项目所属的IAM项目（未指定此参数时，日志服务会将日志项目添加到名为default的IAM项目中）
+        :type iam_project_name: str
+        :param tags: 日志项目标签信息
+        :type tags: List[TagInfo]
         """
         self.page_number = page_number
         self.page_size = page_size
         self.project_name = project_name
         self.project_id = project_id
         self.is_full_name = is_full_name
+        self.iam_project_name = iam_project_name
+        self.tags = tags
 
     def check_validation(self):
         """
@@ -145,6 +167,17 @@ class DescribeProjectsRequest(TLSRequest):
         """
         return True
 
+    def get_api_input(self):
+        body = super(DescribeProjectsRequest, self).get_api_input()
+
+        if self.tags is not None:
+            body[TAGS] = []
+            for tag in self.tags:
+                body[TAGS].append(tag.json())
+            body[TAGS] = json.dumps(body[TAGS])
+
+        return body
+
 
 class CreateTopicRequest(TLSRequest):
     def __init__(self, topic_name: str, project_id: str, ttl: int, shard_count: int, description: str = None,
@@ -152,29 +185,29 @@ class CreateTopicRequest(TLSRequest):
                  time_key: str = None, time_format: str = None, tags: List[TagInfo] = None, log_public_ip: bool = True):
         """
         :param topic_name: 日志主题名称
-        :type topic_name: string
-        :param project_id: 日志主题所属的日志项目 ID
-        :type project_id:str
-        :param ttl:日志在日志服务中的保存时间, 单位天。默认30天
-        :type ttl:int
-        :param shard_count: 日志分区的数量，默认创建 1 个分区，取值范围为 1～10
-        :type shard_count:int
+        :type topic_name: str
+        :param project_id: 日志主题所属的日志项目ID
+        :type project_id: str
+        :param ttl: 日志在日志服务中的保存时间（单位天，默认30天）
+        :type ttl: int
+        :param shard_count: 日志分区的数量（默认创建1个分区，取值范围为1～10）
+        :type shard_count: int
         :param description: 日志主题描述
-        :type description:str
-        :param auto_split 是否开启分区的自动分裂功能
-        :type auto_split bool
-        :param max_split_shard 分区的最大分裂数，即分区分裂后，所有分区的最大数量
-        :type max_split_shard int
-        :param enable_tracking 是否开启WebTracking功能
-        :type enable_tracking bool
-        :param time_key 日志时间字段的字段名称
-        :type time_key str
-        :param time_format 时间字段的解析格式
-        :type time_format str
-        :param tags 日志主题标签信息
-        :type tags List[TagInfo]
-        :param log_public_ip 是否开启记录外网IP功能
-        :type log_public_ip bool
+        :type description: str
+        :param auto_split: 是否开启分区的自动分裂功能
+        :type auto_split: bool
+        :param max_split_shard: 分区的最大分裂数，即分区分裂后，所有分区的最大数量
+        :type max_split_shard: int
+        :param enable_tracking: 是否开启WebTracking功能
+        :type enable_tracking: bool
+        :param time_key: 日志时间字段的字段名称
+        :type time_key: str
+        :param time_format: 时间字段的解析格式
+        :type time_format: str
+        :param tags: 日志主题标签信息
+        :type tags: List[TagInfo]
+        :param log_public_ip: 是否开启记录外网IP功能
+        :type log_public_ip: bool
         """
         self.topic_name = topic_name
         self.project_id = project_id
@@ -197,7 +230,7 @@ class CreateTopicRequest(TLSRequest):
         if self.topic_name is None or self.project_id is None or self.ttl is None or self.shard_count is None:
             return False
         return True
-    
+
     def get_api_input(self):
         body = super(CreateTopicRequest, self).get_api_input()
 
@@ -206,8 +239,9 @@ class CreateTopicRequest(TLSRequest):
             for tag in self.tags:
                 body[TAGS].append(tag.json())
 
-        del body["LogPublicIp"]
-        body[LOG_PUBLIC_IP] = self.log_public_ip
+        if self.log_public_ip is not None:
+            del body["LogPublicIp"]
+            body[LOG_PUBLIC_IP] = self.log_public_ip
 
         return body
 
@@ -232,29 +266,29 @@ class DeleteTopicRequest(TLSRequest):
 
 class ModifyTopicRequest(TLSRequest):
     def __init__(self, topic_id: str, topic_name: str = None, ttl: int = None, description: str = None,
-                 auto_split: bool = True, max_split_shard: int = 10, enable_tracking: bool = False,
-                 time_key: str = None, time_format: str = None, log_public_ip: bool = True):
+                 auto_split: bool = None, max_split_shard: int = None, enable_tracking: bool = None,
+                 time_key: str = None, time_format: str = None, log_public_ip: bool = None):
         """
-        :param topic_id:日志主题 ID
-        :type topic_id:str
+        :param topic_id:日志主题ID
+        :type topic_id: str
         :param topic_name: 日志主题名称
-        :type topic_name: string
-        :param ttl:日志在日志服务中的保存时间, 单位天。默认30天
-        :type ttl:int
+        :type topic_name: str
+        :param ttl: 日志在日志服务中的保存时间（单位天，默认30天）
+        :type ttl: int
         :param description: 日志主题描述
-        :type description:str
-        :param auto_split 是否开启分区的自动分裂功能
-        :type auto_split bool
-        :param max_split_shard 分区的最大分裂数，即分区分裂后，所有分区的最大数量
-        :type max_split_shard int
-        :param enable_tracking 是否开启WebTracking功能
-        :type enable_tracking bool
-        :param time_key 日志时间字段的字段名称
-        :type time_key str
-        :param time_format 时间字段的解析格式
-        :type time_format str
-        :param log_public_ip 是否开启记录外网IP功能
-        :type log_public_ip bool
+        :type description: str
+        :param auto_split: 是否开启分区的自动分裂功能
+        :type auto_split: bool
+        :param max_split_shard: 分区的最大分裂数，即分区分裂后，所有分区的最大数量
+        :type max_split_shard: int
+        :param enable_tracking: 是否开启WebTracking功能
+        :type enable_tracking: bool
+        :param time_key: 日志时间字段的字段名称
+        :type time_key: str
+        :param time_format: 时间字段的解析格式
+        :type time_format: str
+        :param log_public_ip: 是否开启记录外网IP功能
+        :type log_public_ip: bool
         """
         self.topic_id = topic_id
         self.topic_name = topic_name
@@ -279,8 +313,9 @@ class ModifyTopicRequest(TLSRequest):
     def get_api_input(self):
         body = super(ModifyTopicRequest, self).get_api_input()
 
-        del body["LogPublicIp"]
-        body[LOG_PUBLIC_IP] = self.log_public_ip
+        if self.log_public_ip is not None:
+            del body["LogPublicIp"]
+            body[LOG_PUBLIC_IP] = self.log_public_ip
 
         return body
 
@@ -307,17 +342,17 @@ class DescribeTopicsRequest(TLSRequest):
     def __init__(self, project_id: str, page_number: int = 1, page_size: int = 20,
                  topic_name: str = None, topic_id: str = None, is_full_name: bool = False, tags: List[TagInfo] = None):
         """
-        :param page_number: 分页查询时的页码。默认为 1
+        :param page_number: 分页查询时的页码（默认为1）
         :type page_number: int
-        :param page_size: 分页大小。默认为 20，最大为 100
+        :param page_size: 分页大小（默认为20，最大为100）
         :type page_size: int
-        :param topic_id:日志主题 ID
-        :type topic_id:str
+        :param topic_id: 日志主题ID
+        :type topic_id: str
         :param topic_name: 日志主题名称
-        :type topic_name: string
-        :param project_id: 日志项目 ID
+        :type topic_name: str
+        :param project_id: 日志项目ID
         :type project_id: str
-        :param is_full_name: 根据TopicName 筛选时，是否精确匹配
+        :param is_full_name: 根据TopicName筛选时，是否精确匹配
         :type is_full_name: bool
         :param tags: 根据日志主题标签进行筛选
         :type tags: List[TagInfo]
@@ -346,23 +381,28 @@ class DescribeTopicsRequest(TLSRequest):
             body[TAGS] = []
             for tag in self.tags:
                 body[TAGS].append(tag.json())
+            body[TAGS] = json.dumps(body[TAGS])
 
         return body
 
 
 class SetIndexRequest(TLSRequest):
-    def __init__(self, topic_id: str, full_text: FullTextInfo = None, key_value: List[KeyValueInfo] = None):
+    def __init__(self, topic_id: str, full_text: FullTextInfo = None, key_value: List[KeyValueInfo] = None,
+                 user_inner_key_value: List[KeyValueInfo] = None):
         """
-        :param topic_id:日志主题 ID
-        :type topic_id:str
+        :param topic_id: 日志主题ID
+        :type topic_id: str
         :param full_text: 全文索引配置
-        :type full_text:FullTextInfo
-        :param key_value:键值索引配置
-        :type key_value:List[KeyValueInfo]
+        :type full_text: FullTextInfo
+        :param key_value: 键值索引配置
+        :type key_value: List[KeyValueInfo]
+        :param user_inner_key_value: 预留字段索引配置
+        :type user_inner_key_value: List[KeyValueInfo]
         """
         self.topic_id = topic_id
         self.full_text = full_text
         self.key_value = key_value
+        self.user_inner_key_value = user_inner_key_value
 
     def get_api_input(self):
         body = {TOPIC_ID: self.topic_id}
@@ -373,21 +413,28 @@ class SetIndexRequest(TLSRequest):
             body[KEY_VALUE] = []
             for key_value_info in self.key_value:
                 body[KEY_VALUE].append(key_value_info.json())
+        if self.user_inner_key_value is not None:
+            body[USER_INNER_KEY_VALUE] = []
+            for key_value_info in self.user_inner_key_value:
+                body[USER_INNER_KEY_VALUE].append(key_value_info.json())
 
         return body
 
 
 class CreateIndexRequest(SetIndexRequest):
-    def __init__(self, topic_id: str, full_text: FullTextInfo = None, key_value: List[KeyValueInfo] = None):
+    def __init__(self, topic_id: str, full_text: FullTextInfo = None, key_value: List[KeyValueInfo] = None,
+                 user_inner_key_value: List[KeyValueInfo] = None):
         """
-        :param topic_id:日志主题 ID
-        :type topic_id:str
+        :param topic_id: 日志主题ID
+        :type topic_id: str
         :param full_text: 全文索引配置
-        :type full_text:FullTextInfo
-        :param key_value:键值索引配置
-        :type key_value:List[KeyValueInfo]
+        :type full_text: FullTextInfo
+        :param key_value: 键值索引配置
+        :type key_value: List[KeyValueInfo]
+        :param user_inner_key_value: 预留字段索引配置
+        :type user_inner_key_value: List[KeyValueInfo]
         """
-        super(CreateIndexRequest, self).__init__(topic_id, full_text, key_value)
+        super(CreateIndexRequest, self).__init__(topic_id, full_text, key_value, user_inner_key_value)
 
     def check_validation(self):
         """
@@ -402,8 +449,8 @@ class CreateIndexRequest(SetIndexRequest):
 class DeleteIndexRequest(TLSRequest):
     def __init__(self, topic_id: str):
         """
-        :param topic_id:日志主题 ID
-        :type topic_id:str
+        :param topic_id: 日志主题ID
+        :type topic_id: str
         """
         self.topic_id = topic_id
 
@@ -418,16 +465,19 @@ class DeleteIndexRequest(TLSRequest):
 
 
 class ModifyIndexRequest(SetIndexRequest):
-    def __init__(self, topic_id: str, full_text: FullTextInfo = None, key_value: List[KeyValueInfo] = None):
+    def __init__(self, topic_id: str, full_text: FullTextInfo = None, key_value: List[KeyValueInfo] = None,
+                 user_inner_key_value: List[KeyValueInfo] = None):
         """
-        :param topic_id:日志主题 ID
-        :type topic_id:str
+        :param topic_id: 日志主题ID
+        :type topic_id: str
         :param full_text: 全文索引配置
-        :type full_text:FullTextInfo
-        :param key_value:键值索引配置
-        :type key_value:List[KeyValueInfo]
+        :type full_text: FullTextInfo
+        :param key_value: 键值索引配置
+        :type key_value: List[KeyValueInfo]
+        :param user_inner_key_value: 预留字段索引配置
+        :type user_inner_key_value: List[KeyValueInfo]
         """
-        super(ModifyIndexRequest, self).__init__(topic_id, full_text, key_value)
+        super(ModifyIndexRequest, self).__init__(topic_id, full_text, key_value, user_inner_key_value)
 
     def check_validation(self):
         """
@@ -442,8 +492,8 @@ class ModifyIndexRequest(SetIndexRequest):
 class DescribeIndexRequest(TLSRequest):
     def __init__(self, topic_id: str):
         """
-        :param topic_id:日志主题 ID
-        :type topic_id:str
+        :param topic_id: 日志主题ID
+        :type topic_id: str
         """
         self.topic_id = topic_id
 
@@ -486,10 +536,6 @@ class PutLogsRequest(TLSRequest):
     def get_api_input(self):
         pb_log_group_list = self.log_group_list.SerializeToString()
 
-        if len(pb_log_group_list) > 5 * 1024 * 1024:
-            raise TLSException(error_code="LogGroupListSizeTooLarge",
-                               error_message="The size of LogGroupList exceeds 5 MB.")
-
         params = {TOPIC_ID: self.topic_id}
         body = {DATA: pb_log_group_list}
         request_headers = {CONTENT_TYPE: APPLICATION_X_PROTOBUF, X_TLS_BODYRAWSIZE: str(len(pb_log_group_list))}
@@ -854,18 +900,21 @@ class CreateDownloadTaskRequest(TLSRequest):
 
 
 class DescribeDownloadTasksRequest(TLSRequest):
-    def __init__(self, topic_id: str, page_number: int = 1, page_size: int = 20):
+    def __init__(self, topic_id: str, page_number: int = 1, page_size: int = 20, task_name: str = None):
         """
-        :param page_number: 分页查询时的页码。默认为 1
+        :param topic_id: 日志主题ID
+        :type topic_id: str
+        :param page_number: 分页查询时的页码（默认为1）
         :type page_number: int
-        :param page_size: 分页大小。默认为 20，最大为 100
+        :param page_size: 分页大小（默认为20，最大为100）
         :type page_size: int
-        :param topic_id:日志主题 ID
-        :type topic_id:str
+        :param task_name: 根据任务名称进行筛选，支持模糊搜索
+        :type task_name: str
         """
         self.topic_id = topic_id
         self.page_number = page_number
         self.page_size = page_size
+        self.task_name = task_name
 
     def check_validation(self):
         """
@@ -922,22 +971,27 @@ class DescribeShardsRequest(TLSRequest):
 class CreateHostGroupRequest(TLSRequest):
     def __init__(self, host_group_name: str, host_group_type: str,
                  host_ip_list: List[str] = None, host_identifier: str = None, auto_update: bool = False,
-                 update_start_time: str = None, update_end_time: str = None):
+                 update_start_time: str = None, update_end_time: str = None,
+                 service_logging: bool = False, iam_project_name: str = None):
         """
-        :param host_group_name:机器组的名称
-        :type host_group_name:str
-        :param host_group_type:机器组的类型：IP、Label
-        :type host_group_type:str
-        :param host_ip_list:机器组的类型：IP、Label
-        :type host_ip_list:List[str]
-        :param host_identifier:机器 IP 列表
-        :type host_identifier:str
-        :param auto_update:是否开启自动升级功能
-        :type auto_update:bool
-        :param update_start_time:自动升级的开始时间
-        :type update_start_time:str
-        :param update_end_time:自动升级的结束时间
-        :type update_end_time:str
+        :param host_group_name: 机器组的名称
+        :type host_group_name: str
+        :param host_group_type: 机器组的类型（IP或Label）
+        :type host_group_type: str
+        :param host_ip_list: 机器IP列表（HostGroupType为IP时必选）
+        :type host_ip_list: List[str]
+        :param host_identifier: 机器标识（HostGroupType为Label时必选）
+        :type host_identifier: str
+        :param auto_update: 是否开启自动升级功能
+        :type auto_update: bool
+        :param update_start_time: 自动升级的开始时间
+        :type update_start_time: str
+        :param update_end_time: 自动升级的结束时间
+        :type update_end_time: str
+        :param service_logging: 是否开启Logcollector服务日志功能
+        :type service_logging: bool
+        :param iam_project_name: 机器组所属的IAM项目名称
+        :type iam_project_name: str
         """
         self.host_group_name = host_group_name
         self.host_group_type = host_group_type
@@ -946,6 +1000,8 @@ class CreateHostGroupRequest(TLSRequest):
         self.auto_update = auto_update
         self.update_start_time = update_start_time
         self.update_end_time = update_end_time
+        self.service_logging = service_logging
+        self.iam_project_name = iam_project_name
 
     def check_validation(self):
         """
@@ -960,8 +1016,8 @@ class CreateHostGroupRequest(TLSRequest):
 class DeleteHostGroupRequest(TLSRequest):
     def __init__(self, host_group_id: str):
         """
-        :param host_group_id:机器组的 ID
-        :type host_group_id:str
+        :param host_group_id: 机器组ID
+        :type host_group_id: str
         """
         self.host_group_id = host_group_id
 
@@ -977,27 +1033,28 @@ class DeleteHostGroupRequest(TLSRequest):
 
 class ModifyHostGroupRequest(TLSRequest):
     def __init__(self, host_group_id: str, host_group_name: str = None, host_group_type: str = None,
-                 host_ip_list: List[str] = None, host_identifier: str = None, auto_update: bool = False,
-                 update_start_time: str = None, update_end_time: str = None):
+                 host_ip_list: List[str] = None, host_identifier: str = None, auto_update: bool = None,
+                 update_start_time: str = None, update_end_time: str = None, service_logging: bool = None):
         """
-        :param host_group_id:机器组的 ID
-        :type host_group_id:str
-        :param host_group_name:机器组的名称
-        :type host_group_name:str
-        :param host_group_type:机器组的类型：IP、Label
-        :type host_group_type:str
-        :param host_ip_list:机器组的类型：IP、Label
-        :type host_ip_list:List[str]
-        :param host_identifier:机器 IP 列表
-        :type host_identifier:str
-        :param auto_update:是否开启自动升级功能
-        :type auto_update:bool
-        :param update_start_time:自动升级的开始时间
-        :type update_start_time:str
-        :param update_end_time:自动升级的结束时间
-        :type update_end_time:str
+        :param host_group_id: 机器组ID
+        :type host_group_id: str
+        :param host_group_name: 机器组的名称
+        :type host_group_name: str
+        :param host_group_type: 机器组的类型（IP或Label）
+        :type host_group_type: str
+        :param host_ip_list: 机器IP列表（HostGroupType为IP时必选）
+        :type host_ip_list: List[str]
+        :param host_identifier: 机器标识（HostGroupType为Label时必选）
+        :type host_identifier: str
+        :param auto_update: 是否开启自动升级功能
+        :type auto_update: bool
+        :param update_start_time: 自动升级的开始时间
+        :type update_start_time: str
+        :param update_end_time: 自动升级的结束时间
+        :type update_end_time: str
+        :param service_logging: 是否开启Logcollector服务日志功能
+        :type service_logging: bool
         """
-
         self.host_group_id = host_group_id
         self.host_group_name = host_group_name
         self.host_group_type = host_group_type
@@ -1006,6 +1063,7 @@ class ModifyHostGroupRequest(TLSRequest):
         self.auto_update = auto_update
         self.update_start_time = update_start_time
         self.update_end_time = update_end_time
+        self.service_logging = service_logging
 
     def check_validation(self):
         """
@@ -1020,8 +1078,8 @@ class ModifyHostGroupRequest(TLSRequest):
 class DescribeHostGroupRequest(TLSRequest):
     def __init__(self, host_group_id: str):
         """
-        :param host_group_id:机器组的 ID
-        :type host_group_id:str
+        :param host_group_id: 机器组ID
+        :type host_group_id: str
         """
         self.host_group_id = host_group_id
 
@@ -1037,22 +1095,36 @@ class DescribeHostGroupRequest(TLSRequest):
 
 class DescribeHostGroupsRequest(TLSRequest):
     def __init__(self, host_group_id: str = None, host_group_name: str = None,
-                 page_number: int = 1, page_size: int = 20):
+                 page_number: int = 1, page_size: int = 20,
+                 auto_update: bool = None, host_identifier: str = None,
+                 service_logging: bool = None, iam_project_name: str = None):
         """
 
-        :param host_group_id:机器组的 ID
-        :type host_group_id:str
-        :param host_group_name:机器组的名称
-        :type host_group_name:str
-        :param page_number: 分页查询时的页码。默认为 1
+        :param host_group_id: 机器组ID
+        :type host_group_id: str
+        :param host_group_name: 机器组名称
+        :type host_group_name: str
+        :param page_number: 分页查询时的页码（默认为1）
         :type page_number: int
-        :param page_size: 分页大小。默认为 20，最大为 100
+        :param page_size: 分页大小（默认为20，最大为100）
         :type page_size: int
+        :param auto_update: 是否开启了自动升级功能
+        :type auto_update: bool
+        :param host_identifier: 机器组标识，不支持模糊查询
+        :type host_identifier: str
+        :param service_logging: 是否已开启服务日志功能
+        :type service_logging: bool
+        :param iam_project_name: 根据机器组所属的IAM项目名称进行筛选（精确匹配）
+        :type iam_project_name: str
         """
         self.host_group_id = host_group_id
         self.host_group_name = host_group_name
         self.page_number = page_number
         self.page_size = page_size
+        self.auto_update = auto_update
+        self.host_identifier = host_identifier
+        self.service_logging = service_logging
+        self.iam_project_name = iam_project_name
 
     def check_validation(self):
         """
@@ -1066,15 +1138,15 @@ class DescribeHostsRequest(TLSRequest):
     def __init__(self, host_group_id: str, ip: str = None, heartbeat_status: int = None,
                  page_number: int = 1, page_size: int = 20):
         """
-        :param host_group_id:机器组的 ID
-        :type host_group_id:str
-        :param ip: 机器 IP
-        :type ip:str
-        :param heartbeat_status:机器心跳状态
-        :type heartbeat_status:int
-        :param page_number: 分页查询时的页码。默认为 1
+        :param host_group_id: 机器组ID
+        :type host_group_id: str
+        :param ip: 机器IP
+        :type ip: str
+        :param heartbeat_status: 机器心跳状态
+        :type heartbeat_status: int
+        :param page_number: 分页查询时的页码（默认为1）
         :type page_number: int
-        :param page_size: 分页大小。默认为 20，最大为 100
+        :param page_size: 分页大小（默认为20，最大为100）
         :type page_size: int
         """
         self.host_group_id = host_group_id
@@ -1096,10 +1168,10 @@ class DescribeHostsRequest(TLSRequest):
 class DeleteHostRequest(TLSRequest):
     def __init__(self, host_group_id: str, ip: str):
         """
-        :param host_group_id:机器组的 ID
-        :type host_group_id:str
-        :param ip: 机器 IP
-        :type ip:str
+        :param host_group_id: 机器组ID
+        :type host_group_id: str
+        :param ip: 机器IP
+        :type ip: str
         """
         self.host_group_id = host_group_id
         self.ip = ip
@@ -1117,11 +1189,11 @@ class DeleteHostRequest(TLSRequest):
 class DescribeHostGroupRulesRequest(TLSRequest):
     def __init__(self, host_group_id: str, page_number: int = 1, page_size: int = 20):
         """
-        :param host_group_id:机器组的 ID
-        :type host_group_id:str
-        :param page_number: 分页查询时的页码。默认为 1
+        :param host_group_id: 机器组ID
+        :type host_group_id: str
+        :param page_number: 分页查询时的页码（默认为1）
         :type page_number: int
-        :param page_size: 分页大小。默认为 20，最大为 100
+        :param page_size: 分页大小（默认为20，最大为100）
         :type page_size: int
         """
         self.host_group_id = host_group_id
@@ -1139,17 +1211,17 @@ class DescribeHostGroupRulesRequest(TLSRequest):
 
 
 class ModifyHostGroupsAutoUpdateRequest(TLSRequest):
-    def __init__(self, host_group_ids: List[str], auto_update: bool = False,
+    def __init__(self, host_group_ids: List[str], auto_update: bool = None,
                  update_start_time: str = None, update_end_time: str = None):
         """
-        :param host_group_ids:机器组 ID 列表
-        :type host_group_ids:List[str]
-        :param auto_update:机器组服务器中安装的 LogCollector 是否开启自动升级功能
-        :type auto_update:bool
-        :param update_start_time:自动升级的开始时间
-        :type update_start_time:str
-        :param update_end_time:自动升级的结束时间
-        :type update_end_time:str
+        :param host_group_ids: 机器组ID列表
+        :type host_group_ids: List[str]
+        :param auto_update: 机器组服务器中安装的LogCollector是否开启自动升级功能
+        :type auto_update: bool
+        :param update_start_time: 自动升级的开始时间
+        :type update_start_time: str
+        :param update_end_time: 自动升级的结束时间
+        :type update_end_time: str
         """
         self.host_group_ids = host_group_ids
         self.auto_update = auto_update
@@ -1166,6 +1238,22 @@ class ModifyHostGroupsAutoUpdateRequest(TLSRequest):
         return True
 
 
+class DeleteAbnormalHostsRequest(TLSRequest):
+    def __init__(self, host_group_id: str):
+        """
+        :param host_group_id: 机器组ID
+        :type host_group_id: str
+        """
+        self.host_group_id = host_group_id
+
+    def check_validation(self):
+        """
+        :return: 参数是否合法
+        :rtype: bool
+        """
+        return self.host_group_id is not None
+
+
 class SetRuleRequest(TLSRequest):
     def __init__(self, rule_name: str = None, paths: List[str] = None, log_type: str = None,
                  extract_rule: ExtractRule = None, exclude_paths: List[ExcludePath] = None,
@@ -1693,7 +1781,7 @@ class ModifyAlarmRequest(SetAlarmRequest):
     def __init__(self, alarm_id: str, alarm_name: str = None, query_request: List[QueryRequest] = None,
                  request_cycle: RequestCycle = None, condition: str = None, alarm_period: int = None,
                  alarm_notify_group: List[str] = None, status: bool = None, trigger_period: int = None,
-                 user_define_msg: str = None, severity: str = "notice", alarm_period_detail: AlarmPeriodSetting = None):
+                 user_define_msg: str = None, severity: str = None, alarm_period_detail: AlarmPeriodSetting = None):
         """
         :param alarm_id: 告警策略ID
         :type alarm_id: str
@@ -2010,6 +2098,31 @@ class ModifyCheckpointRequest(TLSRequest):
                 CHECKPOINT: self.checkpoint}
 
 
+class ResetCheckpointRequest(TLSRequest):
+    def __init__(self, project_id: str, consumer_group_name: str, position: str):
+        """
+        :param project_id: 日志项目ID
+        :type project_id: str
+        :param consumer_group_name: 消费者名称
+        :type consumer_group_name: str
+        :param position: 消费位点
+        :type position: str
+        """
+        self.project_id = project_id
+        self.consumer_group_name = consumer_group_name
+        self.position = position
+
+    def check_validation(self):
+        """
+        :return: 参数是否合法
+        :rtype: bool
+        """
+        return self.project_id is not None and self.consumer_group_name is not None and self.position is not None
+
+    def get_api_input(self):
+        return {PROJECT_ID_UPPERCASE: self.project_id, CONSUMER_GROUP_NAME: self.consumer_group_name, POSITION: self.position}
+
+
 class DescribeCheckpointRequest(TLSRequest):
     def __init__(self, project_id: str, topic_id: str, shard_id: int, consumer_group_name: str):
         """
@@ -2024,6 +2137,10 @@ class DescribeCheckpointRequest(TLSRequest):
         self.consumer_group_name = consumer_group_name
 
     def check_validation(self):
+        """
+        :return: 参数是否合法
+        :rtype: bool
+        """
         return (self.project_id is not None and self.topic_id is not None and self.shard_id is not None
                 and self.consumer_group_name is not None)
 
@@ -2033,3 +2150,55 @@ class DescribeCheckpointRequest(TLSRequest):
         body = {CONSUMER_GROUP_NAME: self.consumer_group_name}
 
         return {PARAMS: params, BODY: body}
+
+
+class AddTagsToResourceRequest(TLSRequest):
+    def __init__(self, resource_type: str, resources_list: List[str], tags: List[TagInfo]):
+        """
+        :param resource_type: 资源类型，支持设置为project或topic
+        :type resource_type: str
+        :param resources_list: 资源列表，即日志项目或日志主题的ID列表
+        :type resources_list: List[str]
+        :param tags: 需要绑定的标签键和标签值数组对象
+        :type tags: List[TagInfo]
+        """
+        self.resource_type = resource_type
+        self.resources_list = resources_list
+        self.tags = tags
+
+    def check_validation(self):
+        """
+        :return: 参数是否合法
+        :rtype: bool
+        """
+        return self.resource_type is not None and self.resources_list is not None and self.tags is not None
+
+    def get_api_input(self):
+        body = {RESOURCE_TYPE: self.resource_type, RESOURCES_LIST: self.resources_list, TAGS: []}
+
+        for tag in self.tags:
+            body[TAGS].append(tag.json())
+
+        return body
+
+
+class RemoveTagsFromResourceRequest(TLSRequest):
+    def __init__(self, resource_type: str, resources_list: List[str], tag_key_list: List[str]):
+        """
+        :param resource_type: 资源类型，支持设置为project或topic
+        :type resource_type: str
+        :param resources_list: 资源列表，即日志项目或日志主题的ID列表
+        :type resources_list: List[str]
+        :param tag_key_list: 待解绑的资源标签键列表
+        :type tag_key_list: List[str]
+        """
+        self.resource_type = resource_type
+        self.resources_list = resources_list
+        self.tag_key_list = tag_key_list
+
+    def check_validation(self):
+        """
+        :return: 参数是否合法
+        :rtype: bool
+        """
+        return self.resource_type is not None and self.resources_list is not None and self.tag_key_list is not None
