@@ -42,6 +42,7 @@ class VisualService(Service):
             "GeneralSegment": ApiInfo("POST", "/", {"Action": "GeneralSegment", "Version": "2020-08-26"}, {}, {}),
             "EnhancePhoto": ApiInfo("POST", "/", {"Action": "EnhancePhoto", "Version": "2020-08-26"}, {}, {}),
             "ConvertPhoto": ApiInfo("POST", "/", {"Action": "ConvertPhoto", "Version": "2020-08-26"}, {}, {}),
+            "ConvertPhotoV2": ApiInfo("POST", "/", {"Action": "ConvertPhotoV2", "Version": "2022-08-31"}, {}, {}),
             "VideoSceneDetect": ApiInfo("POST", "/", {"Action": "VideoSceneDetect", "Version": "2020-08-26"}, {}, {}),
             "OverResolution": ApiInfo("POST", "/", {"Action": "OverResolution", "Version": "2020-08-26"}, {}, {}),
             "GoodsSegment": ApiInfo("POST", "/", {"Action": "GoodsSegment", "Version": "2020-08-26"}, {}, {}),
@@ -84,10 +85,12 @@ class VisualService(Service):
             "VatInvoice": ApiInfo("POST", "/", {"Action": "OcrVatInvoice", "Version": "2020-08-26"}, {}, {}),
             "QuotaInvoice": ApiInfo("POST", "/", {"Action": "OcrQuotaInvoice", "Version": "2020-08-26"}, {}, {}),
             "HairStyle": ApiInfo("POST", "/", {"Action": "HairStyle", "Version": "2020-08-26"}, {}, {}),
+            "HairStyleV2": ApiInfo("POST", "/", {"Action": "HairStyle", "Version": "2022-08-31"}, {}, {}),
             "FacePretty": ApiInfo("POST", "/", {"Action": "FacePretty", "Version": "2020-08-26"}, {}, {}),
             "ImageAnimation": ApiInfo("POST", "/", {"Action": "ImageAnimation", "Version": "2020-08-26"}, {}, {}),
             "CoverVideo": ApiInfo("POST", "/", {"Action": "CoverVideo", "Version": "2020-08-26"}, {}, {}),
             "DollyZoom": ApiInfo("POST", "/", {"Action": "DollyZoom", "Version": "2020-08-26"}, {}, {}),
+            "Img2Video3D": ApiInfo("POST", "/", {"Action": "Img2Video3D", "Version": "2022-08-31"}, {}, {}),
             "PotraitEffect": ApiInfo("POST", "/", {"Action": "PotraitEffect", "Version": "2020-08-26"}, {}, {}),
             "ImageStyleConversion": ApiInfo("POST", "/", {"Action": "ImageStyleConversion", "Version": "2020-08-26"},{}, {}),
             "3DGameCartoon": ApiInfo("POST", "/", {"Action": "3DGameCartoon", "Version": "2020-08-26"}, {}, {}),
@@ -119,10 +122,38 @@ class VisualService(Service):
             "FaceFusionMovieGetResult": ApiInfo("POST", "/", {"Action": "FaceFusionMovieGetResult", "Version": "2022-08-31"}, {},{}),
             "FaceFusionMovie": ApiInfo("POST", "/", {"Action": "FaceFusionMovie", "Version": "2022-08-31"}, {}, {}),
             "TupoCartoon": ApiInfo("POST", "/", {"Action": "TupoCartoon", "Version": "2022-08-31"}, {}, {}),
-            "T2iLDM": ApiInfo("POST", "/", {"Action": "T2iLDM", "Version": "2022-08-31"}, {}, {}),
             "LensVidaVideoSubmitTaskV2": ApiInfo("POST", "/",{"Action": "LensVidaVideoSubmitTaskV2", "Version": "2022-08-31"}, {},{}),
             "LensVidaVideoGetResultV2": ApiInfo("POST", "/",{"Action": "LensVidaVideoGetResultV2", "Version": "2022-08-31"}, {},{}),
             "CertSrcFaceComp": ApiInfo("POST", "/", {"Action": "CertSrcFaceComp", "Version": "2022-08-31"}, {}, {}),
+            "AIGufeng": ApiInfo("POST", "/", {"Action": "AIGufeng", "Version": "2022-08-31"}, {}, {}),
+            "CertConfigInit": ApiInfo("POST", "/", {"Action": "CertConfigInit", "Version": "2022-08-31"}, {}, {}),
+            "CertConfigGet": ApiInfo("POST", "/", {"Action": "CertConfigInit", "Version": "2022-08-31"}, {}, {}),
+            "FaceCompare": ApiInfo("POST", "/", {"Action": "FaceCompare", "Version": "2022-08-31"}, {}, {}),
+            "StillLivenessImg": ApiInfo("POST", "/", {"Action": "StillLivenessImg", "Version": "2022-08-31"}, {}, {}),
+            "CertAuth": ApiInfo("POST", "/", {"Action": "CertAuth", "Version": "2022-08-31"}, {}, {}),
+            "CertVerify": ApiInfo("POST", "/", {"Action": "CertVerify", "Version": "2022-08-31"}, {}, {}),
+            "FaceSwapV2": ApiInfo("POST", "/", {"Action": "FaceSwap", "Version": "2022-08-31"}, {}, {}),
+            "FaceswapAI": ApiInfo("POST", "/", {"Action": "FaceswapAI", "Version": "2022-08-31"}, {}, {}),
+            "CertH5ConfigInit": ApiInfo("POST", "/", {"Action": "CertH5ConfigInit", "Version": "2022-08-31"}, {}, {}),
+            "CertH5Token": ApiInfo("POST", "/", {"Action": "CertH5Token", "Version": "2022-08-31"}, {}, {}),
+            "HighAesSmartDrawing": ApiInfo("POST", "/", {"Action": "HighAesSmartDrawing", "Version": "2022-08-31"}, {},{}),
+            "EmotionPortrait": ApiInfo("POST", "/", {"Action": "EmotionPortrait", "Version": "2022-08-31"}, {}, {}),
+            "Img2ImgInpainting": ApiInfo("POST", "/", {"Action": "Img2ImgInpainting", "Version": "2022-08-31"}, {}, {}),
+            "Img2ImgInpaintingEdit": ApiInfo("POST", "/", {"Action": "Img2ImgInpaintingEdit", "Version": "2022-08-31"},{}, {}),
+            "Img2ImgOutpainting": ApiInfo("POST", "/", {"Action": "Img2ImgOutpainting", "Version": "2022-08-31"}, {},{}),
+            "Img2ImgCreateDisneyStyleNoFace": ApiInfo("POST", "/", {"Action": "Img2ImgCreateDisneyStyleNoFace","Version": "2022-08-31"}, {}, {}),
+            "Img2ImgCreatePastelBoys2D": ApiInfo("POST", "/",{"Action": "Img2ImgCreatePastelBoys2D", "Version": "2022-08-31"}, {},{}),
+            "Img2ImgCreateAesBlueline": ApiInfo("POST", "/",{"Action": "Img2ImgCreateAesBlueline", "Version": "2022-08-31"}, {},{}),
+            "Img2ImgCreateEtherRealMix": ApiInfo("POST", "/",{"Action": "Img2ImgCreateEtherRealMix", "Version": "2022-08-31"}, {},{}),
+            "Img2ImgCreateToonyou": ApiInfo("POST", "/", {"Action": "Img2ImgCreateToonyou", "Version": "2022-08-31"},{}, {}),
+            "Img2ImgCreateAnyloraMakoto": ApiInfo("POST", "/",{"Action": "Img2ImgCreateAnyloraMakoto", "Version": "2022-08-31"}, {},{}),
+            "Img2ImgCreateRevAnimated": ApiInfo("POST", "/",{"Action": "Img2ImgCreateRevAnimated", "Version": "2022-08-31"}, {},{}),
+            "Img2ImgCreateInkAndWater": ApiInfo("POST", "/",{"Action": "Img2ImgCreateInkAndWater", "Version": "2022-08-31"}, {},{}),
+            "Img2ImgWaterColorStyle": ApiInfo("POST", "/",{"Action": "Img2ImgWaterColorStyle", "Version": "2022-08-31"}, {}, {}),
+            "OCRPdfSubmitTask": ApiInfo("POST", "/", {"Action": "OCRPdfSubmitTask", "Version": "2021-08-23"}, {}, {}),
+            "OCRPdfQueryTask": ApiInfo("POST", "/", {"Action": "OCRPdfQueryTask", "Version": "2021-08-23"}, {}, {}),
+            "EntitySegment": ApiInfo("POST", "/", {"Action": "EntitySegment", "Version": "2022-08-31"}, {}, {}),
+            "Img2ImgAnimeAcceleratedMaintainID": ApiInfo("POST", "/", {"Action": "Img2ImgAnimeAcceleratedMaintainID","Version": "2022-08-31"}, {}, {}),
         }
         return api_info
 
@@ -168,6 +199,103 @@ class VisualService(Service):
             except:
                 raise Exception(str(e))
 
+    def img2_img_anime_accelerated_maintain_id(self, form):
+        try:
+            res_json = self.common_json_handler("Img2ImgAnimeAcceleratedMaintainID", form)
+            return res_json
+        except Exception as e:
+            raise Exception(str(e))
+
+    def entity_segment(self, form):
+        try:
+            res_json = self.common_json_handler("EntitySegment", form)
+            return res_json
+        except Exception as e:
+            raise Exception(str(e))
+
+    def ocr_pdf_submit_task(self, form):
+        try:
+            res_json = self.common_json_handler("OCRPdfSubmitTask", form)
+            return res_json
+        except Exception as e:
+            raise Exception(str(e))
+
+    def ocr_pdf_query_task(self, form):
+        try:
+            res_json = self.common_json_handler("OCRPdfQueryTask", form)
+            return res_json
+        except Exception as e:
+            raise Exception(str(e))
+
+    def img2_img_create_disney_style_no_face(self, form):
+        try:
+            res_json = self.common_json_handler("Img2ImgCreateDisneyStyleNoFace", form)
+            return res_json
+        except Exception as e:
+            raise Exception(str(e))
+
+    def img2_img_create_pastel_boys2d(self, form):
+        try:
+            res_json = self.common_json_handler("Img2ImgCreatePastelBoys2D", form)
+            return res_json
+        except Exception as e:
+            raise Exception(str(e))
+
+    def img2_img_create_ether_real_mix(self, form):
+        try:
+            res_json = self.common_json_handler("Img2ImgCreateEtherRealMix", form)
+            return res_json
+        except Exception as e:
+            raise Exception(str(e))
+
+    def img2_img_create_toonyou(self, form):
+        try:
+            res_json = self.common_json_handler("Img2ImgCreateToonyou", form)
+            return res_json
+        except Exception as e:
+            raise Exception(str(e))
+
+    def img2_img_create_anylora_makoto(self, form):
+        try:
+            res_json = self.common_json_handler("Img2ImgCreateAnyloraMakoto", form)
+            return res_json
+        except Exception as e:
+            raise Exception(str(e))
+
+    def img2_img_create_rev_animated(self, form):
+        try:
+            res_json = self.common_json_handler("Img2ImgCreateRevAnimated", form)
+            return res_json
+        except Exception as e:
+            raise Exception(str(e))
+
+    def img2_img_create_aes_blueline(self, form):
+        try:
+            res_json = self.common_json_handler("Img2ImgCreateAesBlueline", form)
+            return res_json
+        except Exception as e:
+            raise Exception(str(e))
+
+    def img2_img_create_ink_and_water(self, form):
+        try:
+            res_json = self.common_json_handler("Img2ImgCreateInkAndWater", form)
+            return res_json
+        except Exception as e:
+            raise Exception(str(e))
+
+    def img2_img_water_color_style(self, form):
+        try:
+            res_json = self.common_json_handler("Img2ImgWaterColorStyle", form)
+            return res_json
+        except Exception as e:
+            raise Exception(str(e))
+    def high_aes_smart_drawing_v2(self, form):
+        try:
+            res_json = self.common_json_handler("HighAesSmartDrawing", form)
+            return res_json
+        except Exception as e:
+            raise Exception(str(e))
+
     def jpcartoon_cut(self, form):
         try:
             res_json = self.common_handler("JPCartoonCut", form)
@@ -175,6 +303,27 @@ class VisualService(Service):
         except Exception as e:
             raise Exception(str(e))
 
+    def img2img_inpainting(self, form):
+        try:
+            res_json = self.common_json_handler("Img2ImgInpainting", form)
+            return res_json
+        except Exception as e:
+            raise Exception(str(e))
+
+    def img2img_inpainting_edit(self, form):
+        try:
+            res_json = self.common_json_handler("Img2ImgInpaintingEdit", form)
+            return res_json
+        except Exception as e:
+            raise Exception(str(e))
+
+    def img2img_outpainting(self, form):
+        try:
+            res_json = self.common_json_handler("Img2ImgOutpainting", form)
+            return res_json
+        except Exception as e:
+            raise Exception(str(e))
+
     def jpcartoon(self, form):
         try:
             res_json = self.common_handler("JPCartoon", form)
@@ -189,13 +338,31 @@ class VisualService(Service):
         except Exception as e:
             raise Exception(str(e))
 
+    def high_aes_smart_drawing(self, form):
+        try:
+            res_json = self.common_json_handler("HighAesSmartDrawing", form)
+            return res_json
+        except Exception as e:
+            raise Exception(str(e))
+
     def face_swap(self, form):
         try:
             res_json = self.common_handler("FaceSwap", form)
             return res_json
         except Exception as e:
             raise Exception(str(e))
-
+    def face_swap_v2(self, form):
+        try:
+            res_json = self.common_json_handler("FaceSwapV2", form)
+            return res_json
+        except Exception as e:
+            raise Exception(str(e))
+    def faceswap_ai(self, form):
+        try:
+            res_json = self.common_json_handler("FaceswapAI", form)
+            return res_json
+        except Exception as e:
+            raise Exception(str(e))
     def ocr_normal(self, form):
         try:
             res_json = self.common_handler("OCRNormal", form)
@@ -238,6 +405,26 @@ class VisualService(Service):
         except Exception as e:
             raise Exception(str(e))
 
+    def convert_photo_v2(self, form):
+        try:
+            res_json = self.common_json_handler("ConvertPhotoV2", form)
+            return res_json
+        except Exception as e:
+            raise Exception(str(e))
+
+    def cert_h5_config_init(self, form):
+        try:
+            res_json = self.common_json_handler("CertH5ConfigInit", form)
+            return res_json
+        except Exception as e:
+            raise Exception(str(e))
+
+    def cert_h5_token(self, form):
+        try:
+            res_json = self.common_json_handler("CertH5Token", form)
+            return res_json
+        except Exception as e:
+            raise Exception(str(e))
     def video_scene_detect(self, form):
         try:
             res_json = self.common_handler("VideoSceneDetect", form)
@@ -540,6 +727,12 @@ class VisualService(Service):
         except Exception as e:
             raise Exception(str(e))
 
+    def hair_style_v2(self, form):
+        try:
+            res_json = self.common_json_handler("HairStyleV2", form)
+            return res_json
+        except Exception as e:
+            raise Exception(str(e))
     def face_pretty(self, form):
         try:
             res_json = self.common_handler("FacePretty", form)
@@ -568,6 +761,19 @@ class VisualService(Service):
         except Exception as e:
             raise Exception(str(e))
 
+    def img2_video3D(self, form):
+        try:
+            res_json = self.common_json_handler("Img2Video3D", form)
+            return res_json
+        except Exception as e:
+            raise Exception(str(e))
+
+    def ai_gufeng(self, form):
+        try:
+            res_json = self.common_json_handler("AIGufeng", form)
+            return res_json
+        except Exception as e:
+            raise Exception(str(e))
     def potrait_effect(self, form):
         try:
             res_json = self.common_handler("PotraitEffect", form)
@@ -709,6 +915,13 @@ class VisualService(Service):
             return res_json
         except Exception as e:
             raise Exception(str(e))
+        
+    def ocr_async_api(self, action, form):
+        try:
+            res_json = self.common_json_handler(action, form)
+            return res_json
+        except Exception as e:
+            raise Exception(str(e))
 
     def image_score_v2(self, body):
         try:
@@ -815,5 +1028,54 @@ class VisualService(Service):
         except Exception as e:
             raise Exception(str(e))
 
+    def cert_config_init(self, form):
+        try:
+            res_json = self.common_json_handler("CertConfigInit", form)
+            return res_json
+        except Exception as e:
+            raise Exception(str(e))
+
+    def cert_config_get(self, body):
+        try:
+            res_json = self.common_json_handler("CertConfigGet", body)
+            return res_json
+        except Exception as e:
+            raise Exception(str(e))
+
+    def face_compare(self, body):
+        try:
+            res_json = self.common_json_handler("FaceCompare", body)
+            return res_json
+        except Exception as e:
+            raise Exception(str(e))
+
+    def still_liveness_img(self, body):
+        try:
+            res_json = self.common_json_handler("StillLivenessImg", body)
+            return res_json
+        except Exception as e:
+            raise Exception(str(e))
+
+    def emotion_portrait(self, body):
+        try:
+            res_json = self.common_json_handler("EmotionPortrait", body)
+            return res_json
+        except Exception as e:
+            raise Exception(str(e))
+
+    def cert_auth(self, body):
+        try:
+            res_json = self.common_json_handler("CertAuth", body)
+            return res_json
+        except Exception as e:
+            raise Exception(str(e))
+
+    def cert_verify(self, body):
+        try:
+            res_json = self.common_json_handler("CertVerify", body)
+            return res_json
+        except Exception as e:
+            raise Exception(str(e))
+
     def set_api_info(self, action, version):
         self.api_info[action] = ApiInfo("POST", "/", {"Action": action, "Version": version}, {}, {})
\ No newline at end of file
